searchData={"items":[{"type":"behaviour","title":"SiteEncrypt","doc":"Functions for interacting with sites managed by SiteEncrypt.","ref":"SiteEncrypt.html"},{"type":"callback","title":"SiteEncrypt.certification/0","doc":"Invoked during startup to obtain certification info.\n\nSee `configure/1` for details.","ref":"SiteEncrypt.html#c:certification/0"},{"type":"macro","title":"SiteEncrypt.configure/1","doc":"Invoke this macro from `certification/0` to return the fully shaped configuration.\n\nThe minimal implementation of `certification/0` looks as follows:\n\n    @impl SiteEncrypt\n    def certification do\n      SiteEncrypt.configure(\n        client: :native,\n        domains: [\"mysite.com\", \"www.mysite.com\"],\n        emails: [\"contact@abc.org\", \"another_contact@abc.org\"],\n\n        # By default the certs will be stored in tmp/site_encrypt_db, which is convenient for\n        # local development. Make sure that tmp folder is gitignored.\n        #\n        # Set OS env var SITE_ENCRYPT_DB on staging/production hosts to some absolute path\n        # outside of the deployment folder. Otherwise, the deploy may delete the db_folder,\n        # which will effectively remove the generated key and certificate files.\n        db_folder:\n          System.get_env(\"SITE_ENCRYPT_DB\", Path.join(\"tmp\", \"site_encrypt_db\")),\n\n        # set OS env var CERT_MODE to \"staging\" or \"production\" on staging/production hosts\n        directory_url:\n          case System.get_env(\"CERT_MODE\", \"local\") do\n            \"local\" -> {:internal, port: 4002}\n            \"staging\" -> \"https://acme-staging-v02.api.letsencrypt.org/directory\"\n            \"production\" -> \"https://acme-v02.api.letsencrypt.org/directory\"\n          end\n      )\n    end","ref":"SiteEncrypt.html#configure/1"},{"type":"macro","title":"Options - SiteEncrypt.configure/1","doc":"* `:client` - Required. Can be either `:native` or `:certbot`.\n\n      The native client requires no extra OS-level dependencies, and it runs faster, which is\n      especially useful in a local development and tests. However, this client is very immature,\n      possibly buggy, and incomplete.\n\n      The certbot client is a wrapper around the [certbot](https://certbot.eff.org/) tool, which has\n      to be installed on the host machine. This client is much more reliable than the native client,\n      but it is also significantly slower.\n\n      As a compromise between these two choices, you can consider running certbot client in\n      production and during CI tests, while using the native client for local development and local\n      tests.\n\n* `:domains` - Required. The list of domains for which the certificate will be obtained. Must\n        contain at least one element.\n\n* `:emails` - Required. The list of email addresses which will be passed to the CA when\n        creating the new account.\n\n* `:db_folder` (`t:String.t/0`) - Required. The folder where site_encrypt stores its data, such as certificates\n        and account keys.\n\n* `:directory_url` - Required. The URL to CA directory resource. It can be either a string\n  (e.g. `\"https://acme-v02.api.letsencrypt.org/directory\"`) or a tuple in the shape of\n  `{:internal, port: local_acme_server_port}`. In the latter case, an internal ACME server\n  will be started at the given port. This is useful for local development and testing.\n\n* `:backup` (`t:String.t/0`) - Path to the backup file. If this option is provided, site_encrypt\n  will backup the entire content of the `:db_folder` to the given path after every successful\n  certification. When the system is being started, if the backup file exists while the\n  `:db_folder` is empty, the system will perform a restore. The generated file will be a\n  zipped tarball. If this option is not provided no backup will be generated.\n\n* `:days_to_renew` (`t:pos_integer/0`) - A positive integer which determines the next renewal attempt. For example, if this value is\n  30, the certificate will be renewed if it expires in 30 days or less. The default value is `30`.\n\n* `:log_level` - Logger level for info messages. The default value is `:info`.\n\n* `:key_size` (`t:pos_integer/0`) - The size used for generating private keys. The default value is `4096`.\n\n* `:mode` - When set to `:auto`, the certificate will be automatically created or renewed when needed.\n\n  When set to `:manual`, you need to start the certification manually, using functions such as\n  `SiteEncrypt.force_certify/1` or `SiteEncrypt.dry_certify/2`. This can be useful for the\n  first deploy, where you want to manually test the certification. In `:test` mix environment\n  the mode is always `:manual`.\n\n  The default value is `:auto`.","ref":"SiteEncrypt.html#configure/1-options"},{"type":"function","title":"SiteEncrypt.dry_certify/2","doc":"Generates a new throwaway certificate for the given site.\n\nThis function will perform the full certification at the given CA server. The new certificate\nwon't be used by the site, nor stored on disk. This is mostly useful to test the certification\nthrough the staging CA server from the production server, which can be done as follows:\n\n    SiteEncrypt.dry_certify(\n      MySystemWeb.Endpoint,\n      directory_url: \"https://acme-staging-v02.api.letsencrypt.org/directory\"\n    )\n\nIf for some reasons you want to apply the certificate to the site, you can pass the returned\npems to `set_certificate/2`.","ref":"SiteEncrypt.html#dry_certify/2"},{"type":"function","title":"SiteEncrypt.force_certify/1","doc":"Unconditionally obtains the new certificate for the site.\n\nBe very careful when invoking this function in production, because you might trip some rate\nlimit at the CA server (see [here](https://letsencrypt.org/docs/rate-limits/) for Let's\nEncrypt limits).","ref":"SiteEncrypt.html#force_certify/1"},{"type":"callback","title":"SiteEncrypt.handle_new_cert/0","doc":"Invoked after the new certificate has been obtained.","ref":"SiteEncrypt.html#c:handle_new_cert/0"},{"type":"function","title":"SiteEncrypt.https_keys/1","doc":"Returns the paths to the certificates and the key for the given site.","ref":"SiteEncrypt.html#https_keys/1"},{"type":"function","title":"SiteEncrypt.refresh_config/1","doc":"Refresh the configuration for a given endpoint.\n\nUse this if your endpoint is dynamically retrieving the list of domains from the database for example and you want to\nupdate the configuration in the registry. In most cases it makes sense to call `SiteEncrypt.force_certify/1` after\nthe config has been refreshed.","ref":"SiteEncrypt.html#refresh_config/1"},{"type":"function","title":"SiteEncrypt.set_certificate/2","doc":"Sets the new site certificate.\n\nThis operation doesn't persist the certificate in the client storage. As a result, if the client\npreviously obtained and stored a valid certificate, that certificate will be used after the\nendpoint is restarted.","ref":"SiteEncrypt.html#set_certificate/2"},{"type":"opaque","title":"SiteEncrypt.certification/0","doc":"","ref":"SiteEncrypt.html#t:certification/0"},{"type":"type","title":"SiteEncrypt.id/0","doc":"Uniquely identifies the site certified via site_encrypt.\n\nThe actual value is determined by the adapter used to start the site. For example, if\n`SiteEncrypt.Phoenix` is used, the site id is the endpoint module.","ref":"SiteEncrypt.html#t:id/0"},{"type":"type","title":"SiteEncrypt.pems/0","doc":"","ref":"SiteEncrypt.html#t:pems/0"},{"type":"module","title":"SiteEncrypt.Acme.Client","doc":"ACME related functions for endpoints managed by `SiteEncrypt`.\n\nThis module exposes higher-level ACME client-side scenarios, such as new account creation, and\ncertification. Normally these functions are invoked automatically by `SiteEncrypt` processes.\n\nThe functions in this module operate on a running endpoint managed by `SiteEncrypt`. For Phoenix\nthis means that the endpoint must be started through `SiteEncrypt.Phoenix`.\n\nSee also `SiteEncrypt.Acme.Client.API` for details about API sessions and lower level API.","ref":"SiteEncrypt.Acme.Client.html"},{"type":"function","title":"SiteEncrypt.Acme.Client.create_certificate/2","doc":"Obtains the new certificate.\n\nThe obtained certificate will not be applied to the endpoint or stored to disk. If you want to\napply the new certificate to the endpoint, you can pass the returned pems to the function\n`SiteEncrypt.set_certificate/2`.","ref":"SiteEncrypt.Acme.Client.html#create_certificate/2"},{"type":"function","title":"SiteEncrypt.Acme.Client.for_existing_account/3","doc":"Returns `API` session for the existing account.","ref":"SiteEncrypt.Acme.Client.html#for_existing_account/3"},{"type":"function","title":"SiteEncrypt.Acme.Client.new_account/2","doc":"Creates the new account.","ref":"SiteEncrypt.Acme.Client.html#new_account/2"},{"type":"module","title":"SiteEncrypt.Acme.Client.API","doc":"Low level API for interacting with an ACME CA server.\n\nThis module is a very incomplete implementation of the ACME client, as described in\n[RFC8555](https://tools.ietf.org/html/rfc8555). Internally, the module uses `Mint.HTTP` to\ncommunicate with the server. All functions will internally make a blocking HTTP request to\nthe server. Therefore it's advised to invoke the functions of this module from within a separate\nprocess, powered by `Task`.\n\nTo use the client, you first need to create the session with `new_session/3`. Then you can\ninteract with the server using the remaining functions of this module. The session doesn't hold\nany resources open, so you can safely use it from multiple processes.","ref":"SiteEncrypt.Acme.Client.API.html"},{"type":"function","title":"SiteEncrypt.Acme.Client.API.authorization/2","doc":"Obtains authorization challenges from the CA.","ref":"SiteEncrypt.Acme.Client.API.html#authorization/2"},{"type":"function","title":"SiteEncrypt.Acme.Client.API.challenge/2","doc":"Returns the status and the token of the http-01 challenge.","ref":"SiteEncrypt.Acme.Client.API.html#challenge/2"},{"type":"function","title":"SiteEncrypt.Acme.Client.API.fetch_kid/1","doc":"Obtains the key identifier of the existing account.\n\nYou only need to invoke this function if the session is created using the key of the existing\naccount.","ref":"SiteEncrypt.Acme.Client.API.html#fetch_kid/1"},{"type":"function","title":"SiteEncrypt.Acme.Client.API.finalize/3","doc":"Finalizes the given order.","ref":"SiteEncrypt.Acme.Client.API.html#finalize/3"},{"type":"function","title":"SiteEncrypt.Acme.Client.API.get_cert/2","doc":"Obtains the certificate and chain from a finalized order.","ref":"SiteEncrypt.Acme.Client.API.html#get_cert/2"},{"type":"function","title":"SiteEncrypt.Acme.Client.API.new_account/2","doc":"Creates the new account at the CA server.","ref":"SiteEncrypt.Acme.Client.API.html#new_account/2"},{"type":"function","title":"SiteEncrypt.Acme.Client.API.new_order/2","doc":"Creates a new order on the CA server.","ref":"SiteEncrypt.Acme.Client.API.html#new_order/2"},{"type":"function","title":"SiteEncrypt.Acme.Client.API.new_session/3","doc":"Creates a new session to the given CA.\n\n- `directory_url` has to point to the GET directory resource, such as\n  https://acme-v02.api.letsencrypt.org/directory or\n  https://acme-staging-v02.api.letsencrypt.org/directory\n- `account_key` is the private key of the CA account. If you want to create the new account, you\n  need to generate this key yourself, for example with\n\n      JOSE.JWK.generate_key({:rsa, _key_size = 4096})\n\n  Note that this will not create the account. You need to invoke `new_account/2` to do that.\n  It is your responsibility to safely store the private key somewhere.\n\n  If you want to access the existing account, you should pass the same key used for the account\n  creation. In this case you'll usually need to invoke `fetch_kid/1` to fetch the key identifier\n  from the CA server.\n\nNote that this function will make an in-process GET HTTP request to the given directory URL.","ref":"SiteEncrypt.Acme.Client.API.html#new_session/3"},{"type":"function","title":"SiteEncrypt.Acme.Client.API.order_status/2","doc":"Obtains the status of the given order.","ref":"SiteEncrypt.Acme.Client.API.html#order_status/2"},{"type":"type","title":"SiteEncrypt.Acme.Client.API.challenge/0","doc":"","ref":"SiteEncrypt.Acme.Client.API.html#t:challenge/0"},{"type":"type","title":"SiteEncrypt.Acme.Client.API.directory/0","doc":"","ref":"SiteEncrypt.Acme.Client.API.html#t:directory/0"},{"type":"type","title":"SiteEncrypt.Acme.Client.API.error/0","doc":"","ref":"SiteEncrypt.Acme.Client.API.html#t:error/0"},{"type":"type","title":"SiteEncrypt.Acme.Client.API.order/0","doc":"","ref":"SiteEncrypt.Acme.Client.API.html#t:order/0"},{"type":"type","title":"SiteEncrypt.Acme.Client.API.session/0","doc":"","ref":"SiteEncrypt.Acme.Client.API.html#t:session/0"},{"type":"type","title":"SiteEncrypt.Acme.Client.API.session_opts/0","doc":"","ref":"SiteEncrypt.Acme.Client.API.html#t:session_opts/0"},{"type":"type","title":"SiteEncrypt.Acme.Client.API.status/0","doc":"","ref":"SiteEncrypt.Acme.Client.API.html#t:status/0"},{"type":"behaviour","title":"SiteEncrypt.Adapter","doc":"","ref":"SiteEncrypt.Adapter.html"},{"type":"function","title":"SiteEncrypt.Adapter.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\nSee `Supervisor`.","ref":"SiteEncrypt.Adapter.html#child_spec/1"},{"type":"callback","title":"SiteEncrypt.Adapter.config/2","doc":"","ref":"SiteEncrypt.Adapter.html#c:config/2"},{"type":"callback","title":"SiteEncrypt.Adapter.http_port/2","doc":"","ref":"SiteEncrypt.Adapter.html#c:http_port/2"},{"type":"function","title":"SiteEncrypt.Adapter.refresh_config/1","doc":"Refresh the configuration for a given endpoint","ref":"SiteEncrypt.Adapter.html#refresh_config/1"},{"type":"function","title":"SiteEncrypt.Adapter.start_link/3","doc":"","ref":"SiteEncrypt.Adapter.html#start_link/3"},{"type":"module","title":"SiteEncrypt.Phoenix","doc":"`SiteEncrypt` adapter for Phoenix endpoints.","ref":"SiteEncrypt.Phoenix.html"},{"type":"module","title":"Usage - SiteEncrypt.Phoenix","doc":"1. Add `use SiteEncrypt.Phoenix` to your endpoint immediately after `use Phoenix.Endpoint`\n2. Configure https via `configure_https/2`.\n3. Add the implementation of `c:SiteEncrypt.certification/0` to the endpoint (the\n  `@behaviour SiteEncrypt` is injected when this module is used).\n4. Start the endpoint by providing `{SiteEncrypt.Phoenix, PhoenixDemo.Endpoint}` as a supervisor child.","ref":"SiteEncrypt.Phoenix.html#module-usage"},{"type":"function","title":"SiteEncrypt.Phoenix.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"SiteEncrypt.Phoenix.html#child_spec/1"},{"type":"macro","title":"SiteEncrypt.Phoenix.configure_https/2","doc":"Merges paths to key and certificates to the `:https` configuration of the endpoint config for Cowboy.\n\nInvoke this macro from `c:Phoenix.Endpoint.init/2` to complete the https configuration:\n\n    defmodule MyEndpoint do\n      # ...\n\n      @impl Phoenix.Endpoint\n      def init(_key, config) do\n        # this will merge key, cert, and chain into `:https` configuration from config.exs\n        {:ok, SiteEncrypt.Phoenix.configure_https(config)}\n\n        # to completely configure https from `init/2`, invoke:\n        #   SiteEncrypt.Phoenix.configure_https(config, port: 4001, ...)\n      end\n\n      # ...\n    end\n\nThe `options` are any valid adapter HTTPS options. For many great tips on configuring HTTPS for\nproduction refer to the [Plug HTTPS guide](https://hexdocs.pm/plug/https.html#content).","ref":"SiteEncrypt.Phoenix.html#configure_https/2"},{"type":"function","title":"SiteEncrypt.Phoenix.start_link/1","doc":"Starts the endpoint managed by `SiteEncrypt`.","ref":"SiteEncrypt.Phoenix.html#start_link/1"},{"type":"module","title":"SiteEncrypt.Phoenix.Test","doc":"Helper for testing the certification.","ref":"SiteEncrypt.Phoenix.Test.html"},{"type":"module","title":"Usage - SiteEncrypt.Phoenix.Test","doc":"defmodule MyEndpoint.CertificationTest do\n      use ExUnit.Case, async: false\n      import SiteEncrypt.Phoenix.Test\n\n      test \"certification\" do\n        clean_restart(MyEndpoint)\n        cert = get_cert(MyEndpoint)\n        assert cert.domains == ~w/mysite.com www.mysite.com/\n      end\n    end\n\nFor this to work, you need to use the internal ACME server during tests.\nRefer to `SiteEncrypt.configure/1` for details.\n\nAlso note that this test will restart the endpoint. In addition, it will configure Phoenix to\nserve the traffic. Therefore, make sure you pick a different set of ports in test, if you want\nto be able to run the tests while the system is started.\n\nDue to endpoint being restarted, the test case has to be marked as `async: false`.","ref":"SiteEncrypt.Phoenix.Test.html#module-usage"},{"type":"function","title":"SiteEncrypt.Phoenix.Test.clean_restart/1","doc":"Restarts the endpoint, removing all site_encrypt folders in the process.\n\nAfter the restart, the new certificate will be obtained.","ref":"SiteEncrypt.Phoenix.Test.html#clean_restart/1"},{"type":"function","title":"SiteEncrypt.Phoenix.Test.get_cert/1","doc":"Obtains the certificate for the given endpoint.\n\nThe certificate is obtained by establishing an SSL connection. Therefore, for this function to\nwork, the endpoint has to be serving traffic. This will happen if you previously invoked\n`clean_restart/1`.","ref":"SiteEncrypt.Phoenix.Test.html#get_cert/1"},{"type":"extras","title":"SiteEncrypt","doc":"# SiteEncrypt\n\n[![hex.pm](https://img.shields.io/hexpm/v/parent.svg?style=flat-square)](https://hex.pm/packages/site_encrypt)\n[![hexdocs.pm](https://img.shields.io/badge/docs-latest-green.svg?style=flat-square)](https://hexdocs.pm/site_encrypt/)\n![Build Status](https://github.com/sasa1977/site_encrypt/workflows/site_encrypt/badge.svg)\n\nThis project aims to provide integrated certification via [Let's encrypt](https://letsencrypt.org/) for sites implemented in Elixir.\n\nIntegrated certification means that you don't need to run any other OS process in background. Start your site for the first time, and the system will obtain the certificate, and periodically renew it before it expires.\n\nThe target projects are small-to-medium Elixir based sites which don't sit behind reverse proxies such as nginx.","ref":"readme.html"},{"type":"extras","title":"Status - SiteEncrypt","doc":"- The library is tested in a [simple production](https://www.theerlangelist.com), where it has been constantly running since mid 2018.\n- Native Elixir client is very new, and not considered stable. If you prefer reliable behaviour, use the Certbot client. This will require installing [Certbot](https://certbot.eff.org/) >= 0.31\n- The API is not stable. Expect breaking changes in the future.","ref":"readme.html#status"},{"type":"extras","title":"Quick start - SiteEncrypt","doc":"A basic demo Phoenix project is available [here](https://github.com/sasa1977/site_encrypt/tree/master/demos/phoenix).\n\n1. Add the dependency to `mix.exs`:\n\n    ```elixir\n    defmodule PhoenixDemo.Mixfile do\n      # ...\n\n      defp deps do\n        [\n          # ...\n          {:site_encrypt, \"~> 0.5\"}\n        ]\n      end\n    end\n    ```\n\n    Don't forget to invoke `mix.deps` after that.\n\n1. Expand your endpoint\n\n    ```elixir\n    defmodule PhoenixDemo.Endpoint do\n      # ...\n\n      # add this after `use Phoenix.Endpoint`\n      use SiteEncrypt.Phoenix\n\n      # ...\n\n      @impl SiteEncrypt\n      def certification do\n        SiteEncrypt.configure(\n          # Note that native client is very immature. If you want a more stable behaviour, you can\n          # provide `:certbot` instead. Note that in this case certbot needs to be installed on the\n          # host machine.\n          client: :native,\n\n          domains: [\"mysite.com\", \"www.mysite.com\"],\n          emails: [\"contact@abc.org\", \"another_contact@abc.org\"],\n\n          # By default the certs will be stored in tmp/site_encrypt_db, which is convenient for\n          # local development. Make sure that tmp folder is gitignored.\n          #\n          # Set OS env var SITE_ENCRYPT_DB on staging/production hosts to some absolute path\n          # outside of the deployment folder. Otherwise, the deploy may delete the db_folder,\n          # which will effectively remove the generated key and certificate files.\n          db_folder:\n            System.get_env(\"SITE_ENCRYPT_DB\", Path.join(\"tmp\", \"site_encrypt_db\")),\n\n          # set OS env var CERT_MODE to \"staging\" or \"production\" on staging/production hosts\n          directory_url:\n            case System.get_env(\"CERT_MODE\", \"local\") do\n              \"local\" -> {:internal, port: 4002}\n              \"staging\" -> \"https://acme-staging-v02.api.letsencrypt.org/directory\"\n              \"production\" -> \"https://acme-v02.api.letsencrypt.org/directory\"\n            end\n        )\n      end\n\n      # ...\n    end\n    ```\n\n1. Configure https:\n\n    ```elixir\n    defmodule PhoenixDemo.Endpoint do\n      # ...\n\n      @impl Phoenix.Endpoint\n      def init(_key, config) do\n        # this will merge key, cert, and chain into `:https` configuration from config.exs\n        {:ok, SiteEncrypt.Phoenix.configure_https(config)}\n\n        # to completely configure https from `init/2`, invoke:\n        #   SiteEncrypt.Phoenix.configure_https(config, port: 4001, ...)\n      end\n\n      # ...\n    end\n    ```\n\n1. Start the endpoint via `SiteEncrypt`:\n\n    ```elixir\n    defmodule PhoenixDemo.Application do\n      use Application\n\n      def start(_type, _args) do\n        children = [{SiteEncrypt.Phoenix, PhoenixDemo.Endpoint}]\n        opts = [strategy: :one_for_one, name: PhoenixDemo.Supervisor]\n        Supervisor.start_link(children, opts)\n      end\n\n      # ...\n    end\n    ```\n\n1. Optionally add a certification test\n\n    ```elixir\n    defmodule PhoenixDemo.Endpoint.CertificationTest do\n      use ExUnit.Case, async: false\n      import SiteEncrypt.Phoenix.Test\n\n      test \"certification\" do\n        clean_restart(PhoenixDemo.Endpoint)\n        cert = get_cert(PhoenixDemo.Endpoint)\n        assert cert.domains == ~w/mysite.com www.mysite.com/\n      end\n    end\n    ```\n\nAnd that's it! At this point you can start the system:\n\n```text\n$ iex -S mix phx.server\n\n[info]  Generating a temporary self-signed certificate. This certificate will be used until a proper certificate is issued by the CA server.\n[info]  Running PhoenixDemo.Endpoint with cowboy 2.7.0 at 0.0.0.0:4000 (http)\n[info]  Running PhoenixDemo.Endpoint with cowboy 2.7.0 at 0.0.0.0:4001 (https)\n[info]  Running local ACME server at port 4002\n[info]  Ordering a new certificate for domain mysite.com\n[info]  New certificate for domain mysite.com obtained\n[info]  Certificate successfully obtained!\n```\n\nAnd visit your certified site at https://localhost:4001","ref":"readme.html#quick-start"},{"type":"extras","title":"Testing in production - SiteEncrypt","doc":"In general, the configuration above should work out of the box in production, as long as the domain is correctly setup, and ports properly forwarded, so the HTTP site is externally available at port 80.\n\nIf you want a more manual first deploy test, here's how you can do it:\n\n1. Explicitly set `mode: :manual` in `certification/0`. This means that the site won't automatically certify itself. However, during the first boot it will generate a self-signed certificate.\n\n2. Deploy the site and verify that it's externally reachable via HTTP on port 80.\n\n3. Start a remote `iex` shell session to the running system.\n\n4. Perform a trial certification through the staging Let's Encrypt CA:\n\n    ```elixir\n    iex> SiteEncrypt.dry_certify(\n           MySystemWeb.Endpoint,\n           directory_url: \"https://acme-staging-v02.api.letsencrypt.org/directory\"\n         )\n    ```\n\n  Keep in mind that this can be only invoked in the remote `iex` shell session inside the running system.\n\n  If the certification succeeds, the function will return the key and the certificate. These files won't be stored on disk, and they won't be used by the endpoint.\n\n5. If the trial certification succeeded, you can proceed to start the real certification as follows:\n\n    ```elixir\n    iex> SiteEncrypt.force_certify(MySystemWeb.Endpoint)\n    ```\n\n  Unlike the trial certification, this function will go to the CA as configured by the `certification/0` callback in the endpoint. The key and the certificate files will be stored on the disk, and the site will immediately used them. Therefore, if this function succeeds, you can visit your site via HTTPS.\n\n6. If all went well, remove the `:mode` setting from the `certification/0` callback and redeploy your system.\n\n__Note__: be careful not to invoke these functions too frequently, because you might trip some rate limit on Let's Encrypt. See [here](https://letsencrypt.org/docs/rate-limits/) for more details.","ref":"readme.html#testing-in-production"},{"type":"extras","title":"License - SiteEncrypt","doc":"[MIT](./LICENSE)","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.5.1 - Changelog","doc":"- Support bandit 1.x","ref":"changelog.html#0-5-1"},{"type":"extras","title":"0.5.0 - Changelog","doc":"- added `SiteEncrypt.refresh_config/1`\n- added the support for bandit web server","ref":"changelog.html#0-5-0"},{"type":"extras","title":"0.4.2 - Changelog","doc":"- correctly handle relative paths","ref":"changelog.html#0-4-2"},{"type":"extras","title":"0.4.1 - Changelog","doc":"- use dialyxir only on dev","ref":"changelog.html#0-4-1"},{"type":"extras","title":"0.4.0 - Changelog","doc":"This version upgrades to the Parent 0.11 and changes the internals. Strictly speaking this version doesn't change anything, so it could have been a patch update. However, moving to Parent 0.11 might introduce breaking changes in the client code, so the major version is bumped.","ref":"changelog.html#0-4-0"},{"type":"extras","title":"0.3.1 - Changelog","doc":"- Fixes invalid dependency requirement.","ref":"changelog.html#0-3-1"},{"type":"extras","title":"0.3.0 - Changelog","doc":"#","ref":"changelog.html#0-3-0"},{"type":"extras","title":"Additions and non-breaking changes - Changelog","doc":"- Exposed lower-level ACME client API functions through `SiteEncrypt.Acme.Client` and `SiteEncrypt.Acme.Client.API`.\n- Native client keeps the history of old keys.\n- Key size is configurable, with the default of 4096.\n- Added support for manual production testing through `SiteEncrypt.dry_certify/2`. See \"Testing in production\" section in readme for details.\n- Renewal happens at a random time of day to avoid possible spikes on CA.\n\n#","ref":"changelog.html#additions-and-non-breaking-changes"},{"type":"extras","title":"Breaking changes - Changelog","doc":"- The internal folders structure has been changed. If you're running a site_encrypt system in production and using the certbot client, you need to create the folder `acme-v02.api.letsencrypt.org` (assuming you're using Let's Encrypt production) under `db_folder/certbot`, and then recursively copy the contents of `db_folder/certbot` into the new folder. If you're using the native client, you don't need to do anything.","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"0.2.0 - Changelog","doc":"#","ref":"changelog.html#0-2-0"},{"type":"extras","title":"Breaking changes - Changelog","doc":"- The interface for writing tests has been changed. A certification test should now be written as\n\n    ```elixir\n    defmodule MyEndpoint.CertificationTest do\n      use ExUnit.Case, async: false\n      import SiteEncrypt.Phoenix.Test\n\n      test \"certification\" do\n        clean_restart(MyEndpoint)\n        cert = get_cert(MyEndpoint)\n        assert cert.domains == ~w/mysite.com www.mysite.com/\n      end\n    end\n    ```","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"0.1.0 - Changelog","doc":"- added a basic native ACME client\n- simplified interface\n- improved tests\n- expanded docs\n\nThis version introduces many breaking changes. If you've been using a pre 0.1 version, here's how to upgrade your project:\n\n1. In your endpoint, replace `@behaviour SiteEncrypt` with `use SiteEncrypt.Phoenix`\n2. Also in the endpoint, change the `certification/0` callback to pass the options to `SiteEncrypt.configure/1` instead of just returning them.\n3. Changes in options:\n    - `:mode` is no longer supported. Manual mode will be automatically set in tests.\n    - use `:domains` instead of `:domain` and `:extra_domain`\n    - `:ca_url` has been renamed to `directory_url`\n    - `:email` has been renamed to `emails` and must be a list\n    - `:base_folder` has been renamed to `:db_folder`\n    - `:cert_folder` is no longer supported. It will chosen automatically inside the `:db_folder`\n4. The internal folders structure has been changed. If you're running a site_encrypt system in production, you need to create the folder called `certbot` inside the `:db_folder`, and recurisvely copy top-level folders under `:db_folder` into the newly created `certbot` folder.\n5. If you have been using `SiteEncrypt.Phoenix.Test.verify_certification` for certification testing, drop that test, and add the following module somewhere in your test suite:\n    ```elixir\n    defmodule CertificationTest do\n      use SiteEncrypt.Phoenix.Test, endpoint: MyEndpoint\n    end\n    ```","ref":"changelog.html#0-1-0"}],"content_type":"text/markdown"}